import os
import libcurses as curses
from sys import argv,exit
import documentex
from subprocess import call
from pylatex import Document, Section, Itemize, Command, Math, NoEscape
from pylatex.base_classes import Arguments 

from . import lib_etude_fonction as libef
import libargfunc as libargv

def etude_fonction():

    if len(argv) != 2:
        print("usage : etude_fonction nom_dossier")
        exit(1)

    dossier = argv[1]

    ok = False
    while not ok:
        expression = curses.saisie_message_std('f(x)= ? ')
        expression, ok = libargv.sympify(expression)
        if not ok:
            curses.afficher_message_std(expression)
    # en sortie, expression est une expression sympy utilisable

    ok = False
    while not ok:
        intervalle_definition = curses.saisie_message_std('intervalle de définition ? ')
        intervalle_definition, ok = libargv.sympify_intervalle(intervalle_definition)
        if not ok:
            curses.afficher_message_std(intervalle_definition)

    ok = False
    while not ok:
        intervalle_etude = curses.saisie_message_std("intervalle d'étude (taper entrée si c'est le même que le précédent) ? ")
        intervalle_etude, ok = libargv.sympify_intervalle2(intervalle_etude)
        if intervalle_etude == '' and ok:
            intervalle_etude = intervalle_definition
        if not ok:
            curses.afficher_message_std(intervalle_etude)

    ok = False
    while not ok:
        intervalle_derivabilite = curses.saisie_message_std("intervalle de dérivabilité (taper entrée si c'est le même que l'intervalle de définition) ? ")
        intervalle_derivabilite, ok = libargv.sympify_intervalle2(intervalle_derivabilite)
        if intervalle_derivabilite == '' and ok:
            intervalle_derivabilite = intervalle_definition
        if not ok:
            curses.afficher_message_std(intervalle_derivabilite)



    #(1+sqrt(1+24*x**2))/(6*x)#x*ln(1+1/x)
    #intervalle_definition = Interval.open(0,oo)
    #intervalle_etude = intervalle_definition
    # valeurs utilisées pour tracer le graphe de la fonction
    xmin = -10
    xmax = 10
    ymin = -15
    ymax = 15

    f=libef.Fonction(expression,intervalle_definition)
    df = f.dx(intervalle_derivabilite)
    call(['documentex',dossier,'doc'])
    curr_dir = os.getcwd()
    os.chdir(dossier)
    f.graphe(xmin,xmax,ymin,ymax)
    os.chdir(curr_dir)

    doc=Section("Étude d'une fonction")
    doc.append("Étudions la fonction donnée par ")
    mapsto = Command('mapsto')
    fonction = Math(escape=False)
    doc.append(f.latex_print())
    doc.append(NoEscape(r"Cette fonction est dérivable sur $"+libef.latex(intervalle_derivabilite)+"$ et sa dérivée est la fonction "))
    doc.append(df.latex_print())
    tableau_variations = f.tikztab(intervalle_etude)
    if tableau_variations != '':
        doc.append("On en déduit le tableau de variations suivant")
        doc.append(f.tikztab(intervalle_etude))
        doc.append("Du tableau de variation on en déduit les informations suivantes ")
        with doc.create(Itemize()) as itemize:
            itemize.add_item(NoEscape("<+vos commentaires sur le tableau de variation ici+> "))
    else:
        doc.append(r"<+malheureusement sympy.solveset et sympy.solve sont incapables de trouver les points critiques de cette fonction pour une raison inconnue.+>"+NoEscape("\n"))
    doc.append("Le graphique de la fonction est donné sur la figure ")
    numero=str(1)
    doc.append(Command('ref',arguments=Arguments('fig:'+numero)))
    doc.append(f.display_graphe('graphe de la fonction $x\mapsto '+f.latex()+'$',numero))
    doc.generate_tex(os.path.join(dossier,'example'))
